@@ -1,8 +1,11 @@
+from audmetric import utils
 from audmetric.core.api import (
     accuracy,
     concordance_cc,
     confusion_matrix,
+    detection_error_tradeoff,
     edit_distance,
+    equal_error_rate,
     event_error_rate,
     fscore_per_class,
     mean_absolute_error,
