@@ -24,7 +24,7 @@ def accuracy(
     .. math::
 
         \text{accuracy} = \frac{\text{number of correct predictions}}
-                               {\text{number of incorrect predictions}}
+                               {\text{number of total predictions}}
 
     Args:
         truth: ground truth values/classes
@@ -33,7 +33,8 @@ def accuracy(
             Sample is considered in computation if either prediction or
             ground truth (logical OR) is contained in labels.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
 
     Returns:
@@ -83,7 +84,10 @@ def concordance_cc(
                       \mu_\text{prediction}-\mu_\text{truth})^2}
 
     where :math:`\rho` is the Pearson correlation coefficient,
-    :math:`\mu` the mean and :math:`\sigma^2` the variance.
+    :math:`\mu` the mean
+    and :math:`\sigma^2` the variance.\ :footcite:`Lin1989`
+
+    .. footbibliography::
 
     Args:
         truth: ground truth values
@@ -102,8 +106,8 @@ def concordance_cc(
     """
     assert_equal_length(truth, prediction)
 
-    prediction = np.array(prediction)
-    truth = np.array(truth)
+    prediction = np.array(list(prediction))
+    truth = np.array(list(truth))
 
     if len(prediction) < 2:
         return np.NaN
@@ -140,7 +144,8 @@ def confusion_matrix(
         prediction: predicted values/classes
         labels: included labels in preferred ordering.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
         normalize: normalize confusion matrix over the rows
 
@@ -529,7 +534,8 @@ def fscore_per_class(
         prediction: predicted values/classes
         labels: included labels in preferred ordering.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
         zero_division: set the value to return when there is a zero division
 
@@ -666,8 +672,8 @@ def pearson_cc(
     """
     assert_equal_length(truth, prediction)
 
-    prediction = np.array(prediction)
-    truth = np.array(truth)
+    prediction = np.array(list(prediction))
+    truth = np.array(list(truth))
 
     if len(prediction) < 2 or prediction.std() == 0:
         return np.NaN
@@ -694,7 +700,8 @@ def precision_per_class(
         prediction: predicted values/classes
         labels: included labels in preferred ordering.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
         zero_division: set the value to return when there is a zero division
 
@@ -738,7 +745,8 @@ def recall_per_class(
         prediction: predicted values/classes
         labels: included labels in preferred ordering.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
         zero_division: set the value to return when there is a zero division
 
@@ -811,7 +819,8 @@ def unweighted_average_bias(
         labels: included labels in preferred ordering.
             The bias is computed only on the specified labels.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
         subgroups: included subgroups in preferred ordering.
             The direction of the bias is determined by the ordering of the
@@ -923,7 +932,8 @@ def unweighted_average_fscore(
         prediction: predicted values/classes
         labels: included labels in preferred ordering.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
         zero_division: set the value to return when there is a zero division
 
@@ -965,7 +975,8 @@ def unweighted_average_precision(
         prediction: predicted values/classes
         labels: included labels in preferred ordering.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
         zero_division: set the value to return when there is a zero division
 
@@ -1007,7 +1018,8 @@ def unweighted_average_recall(
         prediction: predicted values/classes
         labels: included labels in preferred ordering.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
         zero_division: set the value to return when there is a zero division
 
@@ -1053,7 +1065,8 @@ def weighted_confusion_error(
             ``[[w_r0_c0, ..., w_r0_cN], ..., [w_rN_c0, ..., w_rN_cN]]``
         labels: included labels in preferred ordering.
             If no labels are supplied,
-            they will inferred from :math:`\{\text{prediction}, \text{truth}\}`
+            they will be inferred from
+            :math:`\{\text{prediction}, \text{truth}\}`
             and ordered alphabetically.
 
     Returns:
