@@ -1,4 +1,5 @@
 import numpy as np
+import pandas as pd
 import pyeer.eer_info
 import pytest
 import sklearn.metrics
@@ -13,6 +14,12 @@ import audmetric
         None,
         False,
     ),
+    (
+        pd.Series(np.random.randint(0, 10, size=5)).astype('Int64'),
+        pd.Series(np.random.randint(0, 10, size=5)).astype('Int64'),
+        None,
+        False,
+    ),
     (
         np.random.randint(0, 10, size=1),
         np.random.randint(0, 10, size=1),
@@ -79,7 +86,10 @@ def test_accuracy(truth, prediction, labels, to_string):
             )
             truth = truth[mask]
             prediction = prediction[mask]
-        accuracy = sklearn.metrics.accuracy_score(truth, prediction)
+        accuracy = sklearn.metrics.accuracy_score(
+            list(truth),
+            list(prediction),
+        )
 
     np.testing.assert_almost_equal(
         audmetric.accuracy(truth, prediction, labels=labels),
@@ -165,7 +175,7 @@ def test_equal_error_rate_warnings():
     # No imposter scores (division by 0)
     truth = np.array([1, 1])
     prediction = np.array([1, 1])
-    warning = 'invalid value encountered in true_divide'
+    warning = 'invalid value encountered'
     with pytest.warns(RuntimeWarning, match=warning):
         eer, stats = audmetric.equal_error_rate(truth, prediction)
         pyeer_stats = pyeer.eer_info.get_eer_stats(
@@ -228,6 +238,10 @@ def test_event_error_rate(truth, prediction, eer):
         np.random.randint(0, 10, size=5),
         np.random.randint(0, 10, size=5),
     ),
+    (
+        pd.Series(np.random.randint(0, 10, size=5)).astype('Int64'),
+        pd.Series(np.random.randint(0, 10, size=5)).astype('Int64'),
+    ),
     (
         np.random.randint(0, 10, size=1),
         np.random.randint(0, 10, size=1),
@@ -249,9 +263,15 @@ def test_event_error_rate(truth, prediction, eer):
         np.zeros(10),
     ),
 ])
-def test_concordancecc(truth, prediction):
+def test_concordance_cc(truth, prediction):
+
+    ccc = audmetric.concordance_cc(truth, prediction)
+
+    prediction = np.array(list(prediction))
+    truth = np.array(list(truth))
+
     if len(prediction) < 2:
-        ccc = np.NaN
+        ccc_expected = np.NaN
     else:
         denominator = (
             prediction.std() ** 2
@@ -259,13 +279,14 @@ def test_concordancecc(truth, prediction):
             + (prediction.mean() - truth.mean()) ** 2
         )
         if denominator == 0:
-            ccc = np.NaN
+            ccc_expected = np.NaN
         else:
-            r = np.corrcoef(prediction, truth)[0][1]
-            ccc = 2 * r * prediction.std() * truth.std() / denominator
+            r = np.corrcoef(list(prediction), list(truth))[0][1]
+            ccc_expected = 2 * r * prediction.std() * truth.std() / denominator
+
     np.testing.assert_almost_equal(
-        audmetric.concordance_cc(truth, prediction),
         ccc,
+        ccc_expected,
     )
 
 
@@ -329,6 +350,7 @@ def test_edit_distance(truth, prediction, edit_distance):
     ([0, 2], 100),
 ])
 def test_mean_absolute_error(value_range, num_elements):
+
     t = np.random.randint(value_range[0], value_range[1], size=num_elements)
     p = np.random.randint(value_range[0], value_range[1], size=num_elements)
 
@@ -337,6 +359,14 @@ def test_mean_absolute_error(value_range, num_elements):
         sklearn.metrics.mean_absolute_error(t, p),
     )
 
+    t = pd.Series(t).astype('Int64')
+    t = pd.Series(t).astype('Int64')
+
+    np.testing.assert_almost_equal(
+        audmetric.mean_absolute_error(t, p),
+        sklearn.metrics.mean_absolute_error(t, p),
+    )
+
 
 @pytest.mark.parametrize('value_range,num_elements', [
     ([0, 10], 5),
@@ -345,6 +375,7 @@ def test_mean_absolute_error(value_range, num_elements):
     ([0, 2], 100),
 ])
 def test_mean_squared_error(value_range, num_elements):
+
     t = np.random.randint(value_range[0], value_range[1], size=num_elements)
     p = np.random.randint(value_range[0], value_range[1], size=num_elements)
 
@@ -353,12 +384,24 @@ def test_mean_squared_error(value_range, num_elements):
         sklearn.metrics.mean_squared_error(t, p),
     )
 
+    t = pd.Series(t).astype('Int64')
+    t = pd.Series(t).astype('Int64')
+
+    np.testing.assert_almost_equal(
+        audmetric.mean_absolute_error(t, p),
+        sklearn.metrics.mean_absolute_error(t, p),
+    )
+
 
 @pytest.mark.parametrize('truth,prediction', [
     (
         np.random.randint(0, 10, size=5),
         np.random.randint(0, 10, size=5),
     ),
+    (
+        pd.Series(np.random.randint(0, 10, size=5)).astype('Int64'),
+        pd.Series(np.random.randint(0, 10, size=5)).astype('Int64'),
+    ),
     (
         np.random.randint(0, 10, size=1),
         np.random.randint(0, 10, size=1),
@@ -380,11 +423,11 @@ def test_mean_squared_error(value_range, num_elements):
         np.zeros(10),
     ),
 ])
-def test_pearsoncc(truth, prediction):
+def test_pearson_cc(truth, prediction):
     if len(prediction) < 2 or prediction.std() == 0:
         pcc = np.NaN
     else:
-        pcc = np.corrcoef(truth, prediction)[0][1]
+        pcc = np.corrcoef(list(truth), list(prediction))[0][1]
     np.testing.assert_almost_equal(
         audmetric.pearson_cc(truth, prediction),
         pcc,
@@ -430,6 +473,12 @@ def test_pearsoncc(truth, prediction):
             None,
             0,
         ),
+        (
+            pd.Series(np.random.randint(0, 10, 5)).astype('Int64'),
+            pd.Series(np.random.randint(0, 10, 5)).astype('Int64'),
+            None,
+            0,
+        ),
         (
             np.random.randint(0, 10, 100),
             np.random.randint(0, 10, 100),
@@ -461,8 +510,8 @@ def test_recall_precision_fscore(truth, prediction, labels, zero_division):
             zero_division=zero_division,
         )
         expected = sklearn_metric(
-            truth,
-            prediction,
+            list(truth),
+            list(prediction),
             average='macro',
             zero_division=zero_division,
         ),
